pub struct LinkListener { /* private fields */ }Expand description
An owned listener for link events.
This is created by LinkListenerLocalBuilder and will receive events as long as it is alive.
When this gets dropped, the listener gets unregistered and no events will be received by it.